@@ -4,7 +4,7 @@ use warnings;
 use Path::Tiny;
 use Cwd;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 my $root;
 
 sub import
@@ -74,7 +74,7 @@ lib::root - find perl root and push lib modules path to @INC
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -194,6 +194,18 @@ If necessary, lib::root also accepts a callback as an option. The callback is ex
 
   use lib::root callback => sub { ... };
 
+=head3 EXAMPLE 5 - GET ROOT DIR
+
+IT is also possible to get the root dir calling the root sub:
+
+  my $rootdir = lib::root->root;
+
+=head3 EXAMPLE 5 - GET ROOT DIR
+
+IT is also possible to get the root dir calling the root sub:
+
+  my $rootdir = lib::root->root;
+
 =head2 SEE ALSO
 
 Similar ideas have been implemented before in the modules below and possibly others
